@@ -377,7 +377,7 @@ class Program(object):
                             ACTION='Program.sync'
                             )
                         cmd = (
-                            'rsync --progress -z '
+                            'rsync --progress -z --copy-links '
                             '{peer}:{path} {dst}'
                             ).format(
                                 peer=server.hostname,
